API Reference — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# API Reference

In this section, you can learn more about how PyProcar is intended parses DFT codes and uses the electronic structure data

Highlights of the API include:

  - Python interface to DFT codes

  - Bands, Dos, and Fermi plotting

cfg

Learn more about PyProcar’s plotting configurations

Configuration Files
core API

Learn more about PyProcar’s data types.

Core API
io API

Learn more about PyProcar’s IO interfaces to DFT codes.

IO API
plotter API

Learn more about PyProcar’s plotters (Density of States, Band Structure)

Plotter API
pyposcar API

Learn more about PyProcar’s pyposcar modulue

PyPoscar API
scripts API

Learn more about PyProcar’s scripts (bandsplot, dosplot, bandsdosplot)

Scripts API